"use strict";

var _react = _interopRequireDefault(require("react"));

var _reactTestRenderer = _interopRequireDefault(require("react-test-renderer"));

var _TagsInput = _interopRequireWildcard(require("../TagsInput"));

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; if (obj != null) { var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj["default"] = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

describe('TagsInput', function () {
  test('paserTags assigns ids to the tags', function () {
    var values = [{
      value: 'foo'
    }, {
      value: 'bar',
      special: true
    }];
    var out = (0, _TagsInput.parseTags)(values);
    expect(out).toHaveLength(2);
    expect(out[0]).toEqual(expect.objectContaining({
      __id: expect.anything()
    }));
    expect(out[1]).toEqual(expect.objectContaining({
      __id: expect.anything()
    }));
    expect(out[0].__id).not.toEqual(out[1].__id);
  });
  test('stripIds removes only the generated ids', function () {
    var values = [{
      value: 'foo',
      __id: 1
    }, {
      value: 'bar',
      custom: true,
      __id: 2
    }];
    var out = (0, _TagsInput.stripIds)(values);
    expect(out).toHaveLength(2);
    expect(out[0]).toEqual({
      value: 'foo'
    });
    expect(out[1]).toEqual({
      value: 'bar',
      custom: true
    });
  });
  test('getPlainTextTags transform tags to plain text', function () {
    var values = [{
      value: 'foo',
      __id: 1
    }, {
      value: 'bar',
      special: true,
      __id: 2
    }];
    var out = (0, _TagsInput.getPlainTextTags)(values);
    var expected = 'foo,bar';
    expect(out).toEqual(expected);
  });
  test('hasBlacklistedChars catches a string with a blacklisted character', function () {
    var bl = [',', '+'];
    var hasBl = (0, _TagsInput.hasBlacklistedChars)(bl);
    expect(hasBl('exa,ple')).toEqual(true);
    expect(hasBl('test+')).toEqual(true);
    expect(hasBl('clean')).toEqual(false);
  });
  test('hasBlacklistedChars catches a string with multiple blacklisted chars', function () {
    var bl = [',', '+'];
    var hasBl = (0, _TagsInput.hasBlacklistedChars)(bl);
    expect(hasBl('exa,p+le')).toEqual(true);
    expect(hasBl('test+sda/3,2')).toEqual(true);
    expect(hasBl('clean')).toEqual(false);
  });
  describe('parseValuesWith', function () {
    test('parses a single value', function () {
      var parseVal = (0, _TagsInput.parseValuesWith)([]);
      var out = parseVal('foo');
      expect(out).toHaveLength(1);
      expect(out[0]).toEqual({
        value: 'foo'
      });
    });
    test('parses multiple values', function () {
      var parseVal = (0, _TagsInput.parseValuesWith)([]);
      var out = parseVal('foo,bar');
      expect(out).toHaveLength(2);
      expect(out).toEqual([{
        value: 'foo'
      }, {
        value: 'bar'
      }]);
    });
    test('ignores blacklisted values', function () {
      var parseVal = (0, _TagsInput.parseValuesWith)(['+']);
      var out = parseVal('foo,bar,ev+il');
      expect(out).toHaveLength(2);
      expect(out).toEqual([{
        value: 'foo'
      }, {
        value: 'bar'
      }]);
    });
  }); // Snapshots {{{

  describe('snapshots', function () {
    test('renders a plain input', function () {
      var tree = _reactTestRenderer["default"].create(_react["default"].createElement(_TagsInput["default"], null)).toJSON();

      expect(tree).toMatchSnapshot();
      var tags = [{
        value: 'foo'
      }];
      tree = _reactTestRenderer["default"].create(_react["default"].createElement(_TagsInput["default"], {
        tags: tags
      })).toJSON();
      expect(tree).toMatchSnapshot();
    });
    test('renders with a complete component', function () {
      var tree = _reactTestRenderer["default"].create(_react["default"].createElement(_TagsInput["default"], {
        label: "foo",
        placeholder: "foo",
        copyButton: true,
        specialTags: true
      })).toJSON();

      expect(tree).toMatchSnapshot();
    });
    test('renders with a custom tag', function () {
      var tagRenderer = function tagRenderer() {
        return _react["default"].createElement("span", {
          className: "customTag"
        });
      };

      var tree = _reactTestRenderer["default"].create(_react["default"].createElement(_TagsInput["default"], {
        tagRenderer: tagRenderer,
        tags: [{
          value: 'foo'
        }]
      })).toJSON();

      expect(tree).toMatchSnapshot();
    });
  }); // }}}
});